# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

- Nothing yet.

## [0.0.2]

- App folder will now be properly created.

## [0.0.1]

- Support interpolating temperature to get thermal conductivity of copper
- User must supply the property file

[Unreleased]: https://github.com/blakeNaccarato/propshop/compare/0.0.2...HEAD
[0.0.2]: https://github.com/blakeNaccarato/propshop/compare/0.0.1...0.0.2
[0.0.1]: https://github.com/blakeNaccarato/propshop/releases/tag/0.0.1
